summaryrefslogtreecommitdiff
path: root/include/dm/device.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dm/device.h')
-rw-r--r--include/dm/device.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/dm/device.h b/include/dm/device.h
index 5d31a2c715..491542c580 100644
--- a/include/dm/device.h
+++ b/include/dm/device.h
@@ -285,14 +285,14 @@ struct driver {
#define U_BOOT_DRIVER_ALIAS(__name, __alias)
/**
* dev_get_platdata() - Get the platform data for a device
*
* This checks that dev is not NULL, but no other checks for now
*
* @dev Device to check
* @return platform data, or NULL if none
*/
-void *dev_get_platdata(const struct udevice *dev);
+void *dev_get_plat(const struct udevice *dev);
/**
* dev_get_parent_plat() - Get the parent platform data for a device
@@ -285,14 +285,14 @@ struct driver {
#define U_BOOT_DRIVER_ALIAS(__name, __alias)
/**
- * dev_get_platdata() - Get the platform data for a device
+ * dev_get_plat() - Get the platform data for a device
*
* This checks that dev is not NULL, but no other checks for now